import { Page } from "@/pages/base";
import { Button, Container, Link, Typography } from "@material-ui/core";
import { Link as RouterLink, useHistory } from "react-router-dom";
import { route } from "@/routing";
import { InternshipForm } from "@/forms/internship";
import React from "react";
import { ProposalComment } from "@/pages/steps/proposal";
import { useTranslation } from "react-i18next";
import { ProposalPreview } from "@/components/proposalPreview";
import { useSelector } from "react-redux";
import { Internship } from "@/data";
import { AppState } from "@/state/reducer";
import { internshipSerializationTransformer } from "@/serialization";
import { Actions } from "@/components";
import { InternshipProposalActions, useDispatch } from "@/state/actions";
import { StickerCheckOutline, StickerRemoveOutline } from "mdi-material-ui/index";
import { useVerticalSpacing } from "@/styles";

export const InternshipProposalFormPage = () => {
    return <Page title="Zgłoszenie praktyki">
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>Moja praktyka</Link>
                <Typography color="textPrimary">Zgłoszenie praktyki</Typography>
            </Page.Breadcrumbs>
            <Page.Title>Zgłoszenie praktyki</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" }>
            <ProposalComment />
            <InternshipForm/>
        </Container>
    </Page>
}

export const InternshipProposalPreviewPage = () => {
    const { t } = useTranslation();
    const proposal = useSelector<AppState, Internship | null>(state => state.proposal.proposal && internshipSerializationTransformer.reverseTransform(state.proposal.proposal));

    const dispatch = useDispatch();
    const history = useHistory();

    const handleAccept = () => {
        dispatch({ type: InternshipProposalActions.Approve, comment: null });
        history.push(route("home"));
    }

    const handleDiscard = () => {
        dispatch({ type: InternshipProposalActions.Decline, comment: "Well..." });
        history.push(route("home"));
    }

    const classes = useVerticalSpacing(3);

    return <Page title={ t("") }>
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>Moja praktyka</Link>
                <Typography color="textPrimary">Podgląd zgłoszenia</Typography>
            </Page.Breadcrumbs>
            <Page.Title>Moje zgłoszenie</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" } className={ classes.root }>
            <ProposalComment />
            { proposal && <ProposalPreview proposal={ proposal } /> }

            <Actions>
                <Button component={ RouterLink } to={ route("home") } variant="contained" color="primary">
                    { t('go-back') }
                </Button>

                <Button onClick={ handleAccept } color="primary" startIcon={ <StickerCheckOutline /> }>
                    { t('accept') }
                </Button>

                <Button onClick={ handleDiscard } color="secondary" startIcon={ <StickerRemoveOutline /> }>
                    { t('discard') }
                </Button>
            </Actions>
        </Container>
    </Page>
}

export default InternshipProposalFormPage;
